AxisAlignment

Trait AxisAlignment 

pub trait AxisAlignment {
    // Required method
    fn bias(&self) -> f32;
}
An alignment along one axis, which places a block at a bias of the space left beside it.

Required Methods

fn bias(&self) -> f32

-1 the start, 0 the middle, 1 the end.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors